searchData={"content_type":"text/markdown","items":[{"doc":"The ConfigCat Elixir SDK.\n\n`ConfigCat` provides a `Supervisor` that must be added to your applications\nsupervision tree and an API for accessing your ConfigCat settings.","ref":"ConfigCat.html","title":"ConfigCat","type":"module"},{"doc":"Your application's supervision tree might need to be different, but the most\nbasic approach is to add `ConfigCat` as a child of your top-most supervisor.\n\n```elixir\n# lib/my_app/application.ex\ndef start(_type, _args) do\n  children = [\n    # ... other children ...\n    {ConfigCat, [sdk_key: \"YOUR SDK KEY\"]}\n  ]\n\n  opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n  Supervisor.start_link(children, opts)\nend\n```\n\n#","ref":"ConfigCat.html#module-add-configcat-to-your-supervision-tree","title":"Add ConfigCat to Your Supervision Tree - ConfigCat","type":"module"},{"doc":"`ConfigCat` takes a number of keyword arguments:\n\n- `sdk_key`: **REQUIRED** The SDK key for accessing your ConfigCat settings.\n  Go to the [Connect your application](https://app.configcat.com/sdkkey) tab\n  to get your SDK key.\n\n  ```elixir\n  {ConfigCat, [sdk_key: \"YOUR SDK KEY\"]}\n  ```\n\n- `base_url`: **OPTIONAL** Allows you to specify a custom URL for fetching\n  your ConfigCat settings.\n\n  ```elixir\n  {ConfigCat, [sdk_key: \"YOUR SDK KEY\", base_url: \"https://my-cdn.example.com\"]}\n  ```\n\n- `cache`: **OPTIONAL** Custom cache implementation. By default, `ConfigCat`\n  uses its own in-memory cache, but you can also provide the name of a module\n  that implements the `ConfigCat.ConfigCache` behaviour if you want to provide\n  your own cache (e.g. based on Redis). If your cache implementation requires\n  supervision, it is your application's responsibility to provide that.\n\n  ```elixir\n  {ConfigCat, [sdk_key: \"YOUR SDK KEY\", cache: MyCustomCacheModule]}\n  ```\n\n- `cache_policy`: **OPTIONAL** Specifies the [polling\n  mode](https://configcat.com/docs/sdk-reference/elixir#polling-modes) used by\n  `ConfigCat`. Defaults to auto-polling mode with a 60 second poll interval.\n  You can specify a different polling mode or polling interval using\n  `ConfigCat.CachePolicy.auto/1`, `ConfigCat.CachePolicy.lazy/1`, or\n  `ConfigCat.CachePolicy.manual/0`.\n\n  ```elixir\n  {ConfigCat, [sdk_key: \"YOUR SDK KEY\", cache_policy: ConfigCat.CachePolicy.manual()]}\n  ```\n\n- `connect_timeout_milliseconds`: **OPTIONAL** timeout for establishing a TCP\n  or SSL connection, in milliseconds. Default is 8000.\n\n  ```elixir\n  {ConfigCat, [sdk_key: \"YOUR SDK KEY\", connect_timeout_milliseconds: 8000]}\n  ```\n\n- `data_governance`: **OPTIONAL** Describes the location of your feature flag\n  and setting data within the ConfigCat CDN. This parameter needs to be in\n  sync with your Data Governance preferences.  Defaults to `:global`. [More\n  about Data Governance](https://configcat.com/docs/advanced/data-governance).\n\n  ```elixir\n  {ConfigCat, [sdk_key: \"YOUR SDK KEY\", data_governance: :eu_only]}\n  ```\n\n- `default_user`: **OPTIONAL** user object that will be used as fallback when\n  there's no user parameter is passed to the getValue() method.\n\n  ```elixir\n  {ConfigCat, [sdk_key: \"YOUR SDK KEY\", default_user: User.new(\"test@test.com\")]}\n  ```\n\n- `flag_overrides`: **OPTIONAL** Specify a data source to use for [local flag\n  overrides](https://configcat.com/docs/sdk-reference/elixir#flag-overrides).\n  The data source must implement the `ConfigCat.OverrideDataSource` protocol.\n  `ConfigCat.LocalFileDataSource` and `ConfigCat.LocalMapDataSource` are\n  provided for you to use.\n\n- `hooks`: **OPTIONAL** Specify callback functions to be called when\n  particular events are fired by the SDK. See `ConfigCat.Hooks`.\n\n- `http_proxy`: **OPTIONAL** Specify this option if you need to use a proxy\n  server to access your ConfigCat settings. You can provide a simple URL, like\n  `https://my_proxy.example.com` or include authentication information, like\n  `https://user:password@my_proxy.example.com/`.\n\n  ```elixir\n  {ConfigCat, [sdk_key: \"YOUR SDK KEY\", http_proxy: \"https://my_proxy.example.com\"]}\n  ```\n\n- `name`: **OPTIONAL** A unique identifier for this instance of `ConfigCat`.\n  Defaults to `ConfigCat`.  Must be provided if you need to run more than one\n  instance of `ConfigCat` in the same application. If you provide a `name`,\n  you must then pass that name to all of the API functions using the `client`\n  option. See `Multiple Instances` below.\n\n  ```elixir\n  {ConfigCat, [sdk_key: \"YOUR SDK KEY\", name: :unique_name]}\n  ```\n\n  ```elixir\n  ConfigCat.get_value(\"setting\", \"default\", client: :unique_name)\n  ```\n\n- `offline`: **OPTIONAL**  # Indicates whether the SDK should be initialized\n  in offline mode or not.\n\n  ```elixir\n  {ConfigCat, [sdk_key: \"YOUR SDK KEY\", offline: true]}\n  ```\n\n- `read_timeout_milliseconds`: **OPTIONAL** timeout for receiving an HTTP\n  response from the socket, in milliseconds. Default is 5000.\n\n  ```elixir\n  {ConfigCat, [sdk_key: \"YOUR SDK KEY\", read_timeout_milliseconds: 5000]}\n  ```\n\n#","ref":"ConfigCat.html#module-options","title":"Options - ConfigCat","type":"module"},{"doc":"If you need to run more than one instance of `ConfigCat`, there are two ways\nyou can do it.\n\n##","ref":"ConfigCat.html#module-multiple-instances","title":"Multiple Instances - ConfigCat","type":"module"},{"doc":"You can create a module that `use`s `ConfigCat` and then call the ConfigCat\nAPI functions on that module. This is the recommended option, as it makes the\ncalling code a bit clearer and simpler.\n\nYou can pass any of the options listed above as arguments to `use ConfigCat`\nor specify them in your supervisor. Arguments specified by the supervisor take\nprecedence over those provided to `use ConfigCat`.\n\n```elixir\n# lib/my_app/first_flags.ex\ndefmodule MyApp.FirstFlags do\n  use ConfigCat, sdk_key: \"sdk_key_1\"\nend\n\n# lib/my_app/second_flags.ex\ndefmodule MyApp.SecondFlags do\n  use ConfigCat, sdk_key: \"sdk_key_2\"\nend\n\n# lib/my_app/application.ex\ndef start(_type, _args) do\n  children = [\n    # ... other children ...\n    FirstFlags,\n    SecondFlags,\n  ]\n\n  opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n  Supervisor.start_link(children, opts)\nend\n\n\n# Calling code:\nFirstFlags.get_value(\"someKey\", \"default value\")\nSecondFlags.get_value(\"otherKey\", \"other default\")\n```\n\n##","ref":"ConfigCat.html#module-module-based","title":"Module-Based - ConfigCat","type":"module"},{"doc":"If you prefer not to use the module-based solution, you can instead add\nmultiple `ConfigCat` children to your application's supervision tree. You will\nneed to give `ConfigCat` a unique `name` option for each, as well as using\n`Supervisor.child_spec/2` to provide a unique `id` for each instance.\n\nWhen calling the ConfigCat API functions, you'll pass a `client:` keyword\nargument with the unique `name` you gave to that instance.\n\n```elixir\n# lib/my_app/application.ex\ndef start(_type, _args) do\n  children = [\n    # ... other children ...\n    Supervisor.child_spec({ConfigCat, [sdk_key: \"sdk_key_1\", name: :first]}, id: :config_cat_1),\n    Supervisor.child_spec({ConfigCat, [sdk_key: \"sdk_key_2\", name: :second]}, id: :config_cat_2),\n  ]\n\n  opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n  Supervisor.start_link(children, opts)\nend\n\n# Calling code:\nConfigCat.get_value(\"someKey\", \"default value\", client: :first)\nConfigCat.get_value(\"otherKey\", \"other default\", client: :second)\n```","ref":"ConfigCat.html#module-explicit-client","title":"Explicit Client - ConfigCat","type":"module"},{"doc":"Once `ConfigCat` has been started as part of your application's supervision\ntree, you can use its API to access your settings.\n\n```elixir\nConfigCat.get_value(\"isMyAwesomeFeatureEnabled\", false)\n```\n\nBy default, all of the public API functions will communicate with the default\ninstance of the `ConfigCat` application.\n\nIf you are running multiple instances of `ConfigCat`, you must provide the\n`client` option to the functions, passing along the unique name you specified\nabove.\n\n```elixir\nConfigCat.get_value(\"isMyAwesomeFeatureEnabled\", false, client: :second)\n```","ref":"ConfigCat.html#module-use-the-api","title":"Use the API - ConfigCat","type":"module"},{"doc":"Builds a child specification to use in a Supervisor.\n\nNormally not called directly by your code. Instead, it will be\ncalled by your application's Supervisor once you add `ConfigCat`\nto its supervision tree.","ref":"ConfigCat.html#child_spec/1","title":"ConfigCat.child_spec/1","type":"function"},{"doc":"Clears the default user.\n\nReturns `:ok`.\n\n#","ref":"ConfigCat.html#clear_default_user/1","title":"ConfigCat.clear_default_user/1","type":"function"},{"doc":"- `client`: If you are running multiple instances of `ConfigCat`, provide the\n  `client: :unique_name` option, specifying the name you configured for the\n  instance you want to access.","ref":"ConfigCat.html#clear_default_user/1-options","title":"Options - ConfigCat.clear_default_user/1","type":"function"},{"doc":"Force a refresh of the configuration from ConfigCat's CDN.\n\nDepending on the polling mode you're using, `ConfigCat` may automatically\nfetch your configuration during normal operation. Call this function to\nforce a manual refresh when you want one.\n\nIf you are using manual polling mode (`ConfigCat.CachePolicy.manual/0`),\nthis is the only way to fetch your configuration.\n\nReturns `:ok`.\n\n#","ref":"ConfigCat.html#force_refresh/1","title":"ConfigCat.force_refresh/1","type":"function"},{"doc":"- `client`: If you are running multiple instances of `ConfigCat`, provide the\n  `client: :unique_name` option, specifying the name you configured for the\n  instance you want to access.","ref":"ConfigCat.html#force_refresh/1-options","title":"Options - ConfigCat.force_refresh/1","type":"function"},{"doc":"Queries all settings keys in your configuration.\n\n#","ref":"ConfigCat.html#get_all_keys/1","title":"ConfigCat.get_all_keys/1","type":"function"},{"doc":"- `client`: If you are running multiple instances of `ConfigCat`,\n  provide the `client: :unique_name` option, specifying the name you\n  configured for the instance you want to access.","ref":"ConfigCat.html#get_all_keys/1-options","title":"Options - ConfigCat.get_all_keys/1","type":"function"},{"doc":"See `get_all_value_details/2`.","ref":"ConfigCat.html#get_all_value_details/1","title":"ConfigCat.get_all_value_details/1","type":"function"},{"doc":"Fetches the values and evaluation details of all feature flags and settings.\n\nTo use ConfigCat's [targeting](https://configcat.com/docs/advanced/targeting)\nfeature, provide a `ConfigCat.User` struct containing the information used by\nthe targeting rules.\n\nReturns evaluation details for all settings and feature flags, including their\nvalues. If an error occurs while performing the evaluation, it will be\ncaptured in the `:error` field of the individual `ConfigCat.EvaluationDetails`\nstructs.\n\n#","ref":"ConfigCat.html#get_all_value_details/2","title":"ConfigCat.get_all_value_details/2","type":"function"},{"doc":"- `client`: If you are running multiple instances of `ConfigCat`, provide the\n  `client: :unique_name` option, specifying the name you configured for the\n  instance you want to access.","ref":"ConfigCat.html#get_all_value_details/2-options","title":"Options - ConfigCat.get_all_value_details/2","type":"function"},{"doc":"Fetches the values of all feature flags or settings from your configuration.\n\nTo use ConfigCat's [targeting](https://configcat.com/docs/advanced/targeting)\nfeature, provide a `ConfigCat.User` struct containing the information used by\nthe targeting rules.\n\nReturns a map of all key value pairs.\n\n#","ref":"ConfigCat.html#get_all_values/2","title":"ConfigCat.get_all_values/2","type":"function"},{"doc":"- `client`: If you are running multiple instances of `ConfigCat`, provide the\n  `client: :unique_name` option, specifying the name you configured for the\n  instance you want to access.","ref":"ConfigCat.html#get_all_values/2-options","title":"Options - ConfigCat.get_all_values/2","type":"function"},{"doc":"Fetches the name and value of the setting corresponding to a variation id.\n\nReturns a tuple containing the setting name and value, or `nil` if an error\noccurs.\n\n#","ref":"ConfigCat.html#get_key_and_value/2","title":"ConfigCat.get_key_and_value/2","type":"function"},{"doc":"- `client`: If you are running multiple instances of `ConfigCat`, provide the\n  `client: :unique_name` option, specifying the name you configured for the\n  instance you want to access.","ref":"ConfigCat.html#get_key_and_value/2-options","title":"Options - ConfigCat.get_key_and_value/2","type":"function"},{"doc":"See `get_value/4`.","ref":"ConfigCat.html#get_value/3","title":"ConfigCat.get_value/3","type":"function"},{"doc":"Retrieves a setting value from your configuration.\n\nRetrieves the setting named `key` from your configuration. To use ConfigCat's\n[targeting](https://configcat.com/docs/advanced/targeting) feature, provide a\n`ConfigCat.User` struct containing the information used by the targeting\nrules.\n\nReturns the value of the setting, or `default_value` if an error occurs.\n\n#","ref":"ConfigCat.html#get_value/4","title":"ConfigCat.get_value/4","type":"function"},{"doc":"- `client`: If you are running multiple instances of `ConfigCat`, provide the\n  `client: :unique_name` option, specifying the name you configured for the\n  instance you want to access.","ref":"ConfigCat.html#get_value/4-options","title":"Options - ConfigCat.get_value/4","type":"function"},{"doc":"See `get_value_details/4`.","ref":"ConfigCat.html#get_value_details/3","title":"ConfigCat.get_value_details/3","type":"function"},{"doc":"Fetches the value and evaluation details of a feature flag or setting.\n\nRetrieves the setting named `key` from your configuration. To use ConfigCat's\n[targeting](https://configcat.com/docs/advanced/targeting) feature, provide a\n`ConfigCat.User` struct containing the information used by the targeting\nrules.\n\nReturns the evaluation details for the setting, including the value. If an\nerror occurs while performing the evaluation, it will be captured in the\n`:error` field of the `ConfigCat.EvaluationDetails` struct.\n\n#","ref":"ConfigCat.html#get_value_details/4","title":"ConfigCat.get_value_details/4","type":"function"},{"doc":"- `client`: If you are running multiple instances of `ConfigCat`, provide the\n  `client: :unique_name` option, specifying the name you configured for the\n  instance you want to access.","ref":"ConfigCat.html#get_value_details/4-options","title":"Options - ConfigCat.get_value_details/4","type":"function"},{"doc":"Return the current hook callbacks.\n\n#","ref":"ConfigCat.html#hooks/1","title":"ConfigCat.hooks/1","type":"function"},{"doc":"- `client`: If you are running multiple instances of `ConfigCat`, provide the\n  `client: :unique_name` option, specifying the name you configured for the\n  instance you want to access.","ref":"ConfigCat.html#hooks/1-options","title":"Options - ConfigCat.hooks/1","type":"function"},{"doc":"Returns `true` when the SDK is configured not to initiate HTTP requests, otherwise `false`.\n\n#","ref":"ConfigCat.html#offline?/1","title":"ConfigCat.offline?/1","type":"function"},{"doc":"- `client`: If you are running multiple instances of `ConfigCat`, provide the\n  `client: :unique_name` option, specifying the name you configured for the\n  instance you want to access.","ref":"ConfigCat.html#offline?/1-options","title":"Options - ConfigCat.offline?/1","type":"function"},{"doc":"Sets the default user.\n\nReturns `:ok`.\n\n#","ref":"ConfigCat.html#set_default_user/2","title":"ConfigCat.set_default_user/2","type":"function"},{"doc":"- `client`: If you are running multiple instances of `ConfigCat`, provide the\n  `client: :unique_name` option, specifying the name you configured for the\n  instance you want to access.","ref":"ConfigCat.html#set_default_user/2-options","title":"Options - ConfigCat.set_default_user/2","type":"function"},{"doc":"Configures the SDK to not initiate HTTP requests and work only from its cache.\n\nReturns `:ok`.\n\n#","ref":"ConfigCat.html#set_offline/1","title":"ConfigCat.set_offline/1","type":"function"},{"doc":"- `client`: If you are running multiple instances of `ConfigCat`, provide the\n  `client: :unique_name` option, specifying the name you configured for the\n  instance you want to access.","ref":"ConfigCat.html#set_offline/1-options","title":"Options - ConfigCat.set_offline/1","type":"function"},{"doc":"Configures the SDK to allow HTTP requests.\n\nReturns `:ok`.\n\n#","ref":"ConfigCat.html#set_online/1","title":"ConfigCat.set_online/1","type":"function"},{"doc":"- `client`: If you are running multiple instances of `ConfigCat`, provide the\n  `client: :unique_name` option, specifying the name you configured for the\n  instance you want to access.","ref":"ConfigCat.html#set_online/1-options","title":"Options - ConfigCat.set_online/1","type":"function"},{"doc":"Options that can be passed to all API functions.","ref":"ConfigCat.html#t:api_option/0","title":"ConfigCat.api_option/0","type":"type"},{"doc":"Data Governance mode\n\n[More about Data Governance](https://configcat.com/docs/advanced/data-governance)","ref":"ConfigCat.html#t:data_governance/0","title":"ConfigCat.data_governance/0","type":"type"},{"doc":"Identifier of a specific instance of `ConfigCat`.","ref":"ConfigCat.html#t:instance_id/0","title":"ConfigCat.instance_id/0","type":"type"},{"doc":"The name of a configuration setting.","ref":"ConfigCat.html#t:key/0","title":"ConfigCat.key/0","type":"type"},{"doc":"An option that can be provided when starting `ConfigCat`.","ref":"ConfigCat.html#t:option/0","title":"ConfigCat.option/0","type":"type"},{"doc":"","ref":"ConfigCat.html#t:options/0","title":"ConfigCat.options/0","type":"type"},{"doc":"The return value of the `force_refresh/1` function.","ref":"ConfigCat.html#t:refresh_result/0","title":"ConfigCat.refresh_result/0","type":"type"},{"doc":"The actual value of a configuration setting.","ref":"ConfigCat.html#t:value/0","title":"ConfigCat.value/0","type":"type"},{"doc":"The name of a variation being tested.","ref":"ConfigCat.html#t:variation_id/0","title":"ConfigCat.variation_id/0","type":"type"},{"doc":"Represents the [polling mode](https://configcat.com/docs/sdk-reference/elixir#polling-modes) used by ConfigCat.\n\nThe *ConfigCat SDK* supports 3 different polling mechanisms to\nacquire the setting values from *ConfigCat*. After the latest\nsetting values are downloaded, they are stored in the internal\ncache and all requests are served from there.\n\nWith the following polling modes, you can customize the SDK to\nbest fit to your application's lifecycle.","ref":"ConfigCat.CachePolicy.html","title":"ConfigCat.CachePolicy","type":"module"},{"doc":"The *ConfigCat SDK* downloads the latest values and stores them\nautomatically on a regular schedule.\n\nSee `auto/1` below for details.","ref":"ConfigCat.CachePolicy.html#module-auto-polling-default","title":"Auto polling (default) - ConfigCat.CachePolicy","type":"module"},{"doc":"When calling any of the public API functions (like `get_value()`),\nthe *ConfigCat SDK* downloads the latest setting values if they are\nnot present or have expired. In this case the function will wait\nuntil the settings have been fetched before returning.\n\nSee `lazy/1` below for details.","ref":"ConfigCat.CachePolicy.html#module-lazy-loading","title":"Lazy loading - ConfigCat.CachePolicy","type":"module"},{"doc":"Manual polling gives you full control over when the setting\nvalues are downloaded. *ConfigCat SDK* will not update them\nautomatically. Calling `ConfigCat.force_refresh/1` is your\napplication's responsibility.\n\nSee `manual/0` below for details.","ref":"ConfigCat.CachePolicy.html#module-manual-polling","title":"Manual polling - ConfigCat.CachePolicy","type":"module"},{"doc":"Auto-polling mode.\n\nThe *ConfigCat SDK* downloads the latest values and stores them\nautomatically on a regular schedule.\n\nUse the `max_init_wait_time_seconds` option to set the maximum waiting time\nbetween initialization and the first config acquisition. Defaults to 5 seconds\nif not specified.\n\n```elixir\nConfigCat.CachePolicy.auto(max_init_wait_time_seconds: 5)\n```\n\nUse the `poll_interval_seconds` option to change the\npolling interval. Defaults to 60 seconds if not specified.\n\n```elixir\nConfigCat.CachePolicy.auto(poll_interval_seconds: 60)\n```","ref":"ConfigCat.CachePolicy.html#auto/1","title":"ConfigCat.CachePolicy.auto/1","type":"function"},{"doc":"Lazy polling mode.\n\nWhen calling any of the public API functions (like `get_value()`),\nthe *ConfigCat SDK* downloads the latest setting values if they are\nnot present or have expired. In this case the function will wait\nuntil the settings have been fetched before returning.\n\nUse the required `cache_refresh_interval_seconds` option to set the cache\nlifetime.\n\n```elixir\nConfigCat.CachePolicy.lazy(cache_refresh_interval_seconds: 300)\n```","ref":"ConfigCat.CachePolicy.html#lazy/1","title":"ConfigCat.CachePolicy.lazy/1","type":"function"},{"doc":"Manual polling mode.\n\nManual polling gives you full control over when the setting\nvalues are downloaded. *ConfigCat SDK* will not update them\nautomatically. Calling `ConfigCat.force_refresh/1` is your\napplication's responsibility.\n\n```elixir\nConfigCat.CachePolicy.manual()\n```","ref":"ConfigCat.CachePolicy.html#manual/0","title":"ConfigCat.CachePolicy.manual/0","type":"function"},{"doc":"Options for auto-polling mode.","ref":"ConfigCat.CachePolicy.html#t:auto_options/0","title":"ConfigCat.CachePolicy.auto_options/0","type":"type"},{"doc":"Options for lazy-polling mode.","ref":"ConfigCat.CachePolicy.html#t:lazy_options/0","title":"ConfigCat.CachePolicy.lazy_options/0","type":"type"},{"doc":"Callback to call when configuration changes.","ref":"ConfigCat.CachePolicy.html#t:on_changed_callback/0","title":"ConfigCat.CachePolicy.on_changed_callback/0","type":"type"},{"doc":"The polling mode","ref":"ConfigCat.CachePolicy.html#t:t/0","title":"ConfigCat.CachePolicy.t/0","type":"opaque"},{"doc":"Defines configuration-related types used in the rest of the library.","ref":"ConfigCat.Config.html","title":"ConfigCat.Config","type":"module"},{"doc":"The name of a configuration setting.","ref":"ConfigCat.Config.html#t:key/0","title":"ConfigCat.Config.key/0","type":"type"},{"doc":"A collection of configuration settings and preferences.","ref":"ConfigCat.Config.html#t:t/0","title":"ConfigCat.Config.t/0","type":"type"},{"doc":"The actual value of a configuration setting.","ref":"ConfigCat.Config.html#t:value/0","title":"ConfigCat.Config.value/0","type":"type"},{"doc":"The name of a variation being tested.","ref":"ConfigCat.Config.html#t:variation_id/0","title":"ConfigCat.Config.variation_id/0","type":"type"},{"doc":"Defines a configuration cache.\n\nA calling application can optionally supply its own cache implementation to use\nin place of the default in-memory cache by providing the implementation's module name\nas the `:cache` option in `ConfigCat.child_spec/1`.\n\nThe provided implementation must explicitly or implicitly implement this behaviour.\n\nIf the cache implementation is a GenServer or similar, it is the calling\napplication's responsibility to add it to its own supervision tree.","ref":"ConfigCat.ConfigCache.html","title":"ConfigCat.ConfigCache","type":"behaviour"},{"doc":"Fetches the serialized configuration stored under the given cache key.\n\nReturns `{:ok, serialized_config}` if there is a cached configuration or\n`{:error, :not_found}` if not.","ref":"ConfigCat.ConfigCache.html#c:get/1","title":"ConfigCat.ConfigCache.get/1","type":"callback"},{"doc":"Stores an updated serialized configuration under the given cache key.\n\nReturns :ok.","ref":"ConfigCat.ConfigCache.html#c:set/2","title":"ConfigCat.ConfigCache.set/2","type":"callback"},{"doc":"The cache key under which the configuration is stored","ref":"ConfigCat.ConfigCache.html#t:key/0","title":"ConfigCat.ConfigCache.key/0","type":"type"},{"doc":"The result of a cache fetch.","ref":"ConfigCat.ConfigCache.html#t:result/0","title":"ConfigCat.ConfigCache.result/0","type":"type"},{"doc":"Captures the results of evaluating a feature flag.","ref":"ConfigCat.EvaluationDetails.html","title":"ConfigCat.EvaluationDetails","type":"module"},{"doc":"The results of evaluating a feature flag.\n\nFields:\n- `:default_value?`: Indicates whether the default value passed to the setting\n  evaluation functions like `ConfigCat.get_value/3`,\n  `ConfigCat.get_value_details/3`, etc. is used as the result of the\n  evaluation.\n- `:error`: Error message in case evaluation failed.\n- `:fetch_time`: Time of the last successful config download.\n- `:key`: The key of the feature flag or setting.\n- `:matched_targeting_rule`: The targeting rule (if any) that matched during\n  the evaluation and was used to return the evaluated value.\n- `:matched_percentage_option`: The percentage option (if any) that was used\n  to select the evaluated value.\n- `:user`: The `ConfigCat.User` struct used for the evaluation (if available).\n- `:value`: Evaluated value of the feature flag or setting.\n- `:variation_id`: Variation ID of the feature flag or setting (if available).","ref":"ConfigCat.EvaluationDetails.html#t:t/0","title":"ConfigCat.EvaluationDetails.t/0","type":"type"},{"doc":"Subscribe to events fired by the SDK.\n\nHooks are callback functions that are called by the SDK when certain events\nhappen. Client applications can register more than one callback for each hook.\n\nCallbacks are called within the same process that generated the event. Any\nexceptions that are raised by a callback are rescued, logged, and reported to\nany registered `on_error` callbacks.\n\nThe following callbacks are available:\n- `on_client_ready`: This event is sent when the SDK reaches the ready state.\n  If the SDK is set up with lazy load or manual polling it's considered ready\n  right after instantiation. If it's using auto polling, the ready state is\n  reached when the SDK has a valid config JSON loaded into memory either from\n  cache or from HTTP.\n- `on_config_changed(config: map())`: This event is sent when the SDK loads a\n  valid config JSON into memory from cache, and each subsequent time when the\n  loaded config JSON changes via HTTP.\n- `on_flag_evaluated(evaluation_details: EvaluationDetails.t())`: This event\n  is sent each time when the SDK evaluates a feature flag or setting. The\n  event sends the same evaluation details that you would get from\n  get_value_details.\n- on_error(error: String.t()): This event is sent when an error occurs within the\n  ConfigCat SDK.","ref":"ConfigCat.Hooks.html","title":"ConfigCat.Hooks","type":"module"},{"doc":"Add an `on_client_ready` callback.","ref":"ConfigCat.Hooks.html#add_on_client_ready/2","title":"ConfigCat.Hooks.add_on_client_ready/2","type":"function"},{"doc":"Add an `on_config_changed` callback.","ref":"ConfigCat.Hooks.html#add_on_config_changed/2","title":"ConfigCat.Hooks.add_on_config_changed/2","type":"function"},{"doc":"Add an `on_error` callback.","ref":"ConfigCat.Hooks.html#add_on_error/2","title":"ConfigCat.Hooks.add_on_error/2","type":"function"},{"doc":"Add an `on_flag_evaluated` callback.","ref":"ConfigCat.Hooks.html#add_on_flag_evaluated/2","title":"ConfigCat.Hooks.add_on_flag_evaluated/2","type":"function"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ConfigCat.Hooks.html#child_spec/1","title":"ConfigCat.Hooks.child_spec/1","type":"function"},{"doc":"A hook callback is either an anonymous function or a module/function name/extra_arguments tuple.\n\nEach callback is passed specific arguments. These specific arguments are\nprepended to the extra arguments provided in the tuple (if any).\n\nFor example, you might want to define a callback that sends a message to\nanother process which the config changes. You can pass the pid of that process\nas an extra argument:\n\n```elixir\ndef MyModule do\n  def subscribe_to_config_changes(subscriber_pid) do\n    ConfigCat.hooks()\n    |> ConfigCat.Hooks.add_on_config_changed({__MODULE__, :on_config_changed, [subscriber_pid]})\n  end\n\n  def on_config_changed(config, pid) do\n    send pid, {:config_changed, config}\n  end\nend\n```","ref":"ConfigCat.Hooks.html#t:named_callback/0","title":"ConfigCat.Hooks.named_callback/0","type":"type"},{"doc":"","ref":"ConfigCat.Hooks.html#t:on_client_ready_callback/0","title":"ConfigCat.Hooks.on_client_ready_callback/0","type":"type"},{"doc":"","ref":"ConfigCat.Hooks.html#t:on_config_changed_callback/0","title":"ConfigCat.Hooks.on_config_changed_callback/0","type":"type"},{"doc":"","ref":"ConfigCat.Hooks.html#t:on_error_callback/0","title":"ConfigCat.Hooks.on_error_callback/0","type":"type"},{"doc":"","ref":"ConfigCat.Hooks.html#t:on_flag_evaluated_callback/0","title":"ConfigCat.Hooks.on_flag_evaluated_callback/0","type":"type"},{"doc":"","ref":"ConfigCat.Hooks.html#t:option/0","title":"ConfigCat.Hooks.option/0","type":"type"},{"doc":"","ref":"ConfigCat.Hooks.html#t:start_option/0","title":"ConfigCat.Hooks.start_option/0","type":"type"},{"doc":"","ref":"ConfigCat.Hooks.html#t:t/0","title":"ConfigCat.Hooks.t/0","type":"opaque"},{"doc":"Load flag overrides from a file.\n\nSee `ConfigCat.OverrideDataSource` for more details.","ref":"ConfigCat.LocalFileDataSource.html","title":"ConfigCat.LocalFileDataSource","type":"module"},{"doc":"Create a `ConfigCat.OverrideDataSource` that loads overrides from a file.","ref":"ConfigCat.LocalFileDataSource.html#new/2","title":"ConfigCat.LocalFileDataSource.new/2","type":"function"},{"doc":"","ref":"ConfigCat.LocalFileDataSource.html#t:t/0","title":"ConfigCat.LocalFileDataSource.t/0","type":"type"},{"doc":"Use flag overrides from a provided `Map`.\n\nSee `ConfigCat.OverrideDataSource` for more details.","ref":"ConfigCat.LocalMapDataSource.html","title":"ConfigCat.LocalMapDataSource","type":"module"},{"doc":"Create a `ConfigCat.OverrideDataSource` from a map of flag/value pairs.","ref":"ConfigCat.LocalMapDataSource.html#new/2","title":"ConfigCat.LocalMapDataSource.new/2","type":"function"},{"doc":"","ref":"ConfigCat.LocalMapDataSource.html#t:t/0","title":"ConfigCat.LocalMapDataSource.t/0","type":"type"},{"doc":"Don't provide any local flag overrides.\n\nUsed to avoid `is_nil` checks in the rest of the code.\n\nSee `ConfigCat.OverrideDataSource` for more details.","ref":"ConfigCat.NullDataSource.html","title":"ConfigCat.NullDataSource","type":"module"},{"doc":"Create a `ConfigCat.OverrideDataSource` that does nothing.","ref":"ConfigCat.NullDataSource.html#new/0","title":"ConfigCat.NullDataSource.new/0","type":"function"},{"doc":"","ref":"ConfigCat.NullDataSource.html#t:t/0","title":"ConfigCat.NullDataSource.t/0","type":"type"},{"doc":"Data source for local overrides of feature flags and settings.\n\nWith flag overrides you can overwrite the feature flags & settings downloaded\nfrom the ConfigCat CDN with local values. Moreover, you can specify how the\noverrides should apply over the downloaded values. See `t:behaviour/0`.","ref":"ConfigCat.OverrideDataSource.html","title":"ConfigCat.OverrideDataSource","type":"protocol"},{"doc":"Return the selected flag override behaviour.","ref":"ConfigCat.OverrideDataSource.html#behaviour/1","title":"ConfigCat.OverrideDataSource.behaviour/1","type":"function"},{"doc":"Return the local flag overrides from the data source.","ref":"ConfigCat.OverrideDataSource.html#overrides/1","title":"ConfigCat.OverrideDataSource.overrides/1","type":"function"},{"doc":"Flag override behaviour.\n\nThe following 3 behaviours are supported:\n\n- Local/Offline mode (`:local_only`): When evaluating values, the SDK will not\n  use feature flags & settings from the ConfigCat CDN, but it will use all\n  feature flags & settings that are loaded from local-override sources.\n\n- Local over remote (`:local_over_remote`): When evaluating values, the SDK\n  will use all feature flags & settings that are downloaded from the ConfigCat\n  CDN, plus all feature flags & settings that are loaded from local-override\n  sources. If a feature flag or a setting is defined both in the downloaded\n  and the local-override source then the local-override version will take\n  precedence.\n\n- Remote over local (`:remote_over_local`): When evaluating values, the SDK\n  will use all feature flags & settings that are downloaded from the ConfigCat\n  CDN, plus all feature flags & settings that are loaded from local-override\n  sources. If a feature flag or a setting is defined both in the downloaded\n  and the local-override source then the downloaded version will take\n  precedence.","ref":"ConfigCat.OverrideDataSource.html#t:behaviour/0","title":"ConfigCat.OverrideDataSource.behaviour/0","type":"type"},{"doc":"All the types that implement this protocol.","ref":"ConfigCat.OverrideDataSource.html#t:t/0","title":"ConfigCat.OverrideDataSource.t/0","type":"type"},{"doc":"Represents a user in your system; used for ConfigCat's Targeting feature.\n\nThe User Object is an optional parameter when getting a feature flag or\nsetting value from ConfigCat. It allows you to pass potential [Targeting\nrule](https://configcat.com/docs/advanced/targeting) variables to the\nConfigCat SDK.\n\nHas the following properties:\n- `identifier`: **REQUIRED** We recommend using a primary key, email address,\n  or session ID. Enables ConfigCat to differentiate your users from each other\n  and to evaluate the setting values for percentage-based targeting.\n\n- `country`: **OPTIONAL** Fill this for location or country-based targeting.\n  e.g: Turn on a feature for users in Canada only.\n\n- `email`: **OPTIONAL** By adding this parameter you will be able to create\n  Email address-based targeting. e.g: Only turn on a feature for users with\n  @example.com addresses.\n\n- `custom`: **OPTIONAL** This parameter will let you create targeting based on\n  any user data you like. e.g: age, subscription type, user role, device type,\n  app version number, etc. `custom` is a map containing string or atom keys.\n  When evaluating targeting rules, keys are case-sensitive, so make sure you\n  specify your keys with the same capitalization as you use when defining your\n  targeting rules.\n\nAll comparators support string values as User Object attributes (in some cases\nthey need to be provided in a specific format though, see below), but some of\nthem also support other types of values. It depends on the comparator how the\nvalues will be handled. The following rules apply:\n\nText-based comparators (EQUALS, IS_ONE_OF, etc.)\n- accept string values,\n- all other values are automatically converted to string (a warning will be\n  logged but evaluation will continue as normal).\n\nSemVer-based comparators (IS_ONE_OF_SEMVER, LESS_THAN_SEMVER,\nGREATER_THAN_SEMVER, etc.)\n- accept string values containing a properly formatted, valid semver value\n- all other values are considered invalid (a warning will be logged and the\n  currently evaluated targeting rule will be skipped).\n\nNumber-based comparators (EQUALS_NUMBER, LESS_THAN_NUMBER,\nGREATER_THAN_OR_EQUAL_NUMBER, etc.)\n- accept float values and all other numeric values which can safely be\n  converted to float,\n- accept string values containing a properly formatted, valid float value,\n- all other values are considered invalid (a warning will be logged and the\n  currently evaluated targeting rule will be skipped).\n\nDate time-based comparators (BEFORE_DATETIME / AFTER_DATETIME)\n- accept `DateTime` and `NaiveDateTime` values, which are automatically\n  converted to a second-based fractional Unix timestamp (`NaiveDateTime`\n  values are considered to be in UTC),\n- accept float values representing a fractional second-based Unix timestamp\n  and all other numeric values which can safely be converted to float,\n- accept string values containing a properly formatted, valid float value,\n- all other values are considered invalid (a warning will be logged and the\n  currently evaluated targeting rule will be skipped).\n\nString array-based comparators (ARRAY_CONTAINS_ANY_OF /\nARRAY_NOT_CONTAINS_ANY_OF)\n- accept arrays of strings,\n- accept string values containing a valid JSON string which can be\n  deserialized to an array of strings,\n- all other values are considered invalid (a warning will be logged and the\n  currently evaluated targeting rule will be skipped).\n\nWhile `ConfigCat.User` is a struct, we also provide the `new/2` function to\nmake it easier to create a new user object. Pass it the `identifier` and then\neither a keyword list or map containing the other properties you want to\nspecify.\n\ne.g. `ConfigCat.User.new(\"IDENTIFIER\", email: \"user@example.com\")`","ref":"ConfigCat.User.html","title":"ConfigCat.User","type":"module"},{"doc":"Creates a new ConfigCat.User Object.\n\nThis is provided as a convenience to make it easier to create a\nnew user object.\n\nPass it the `identifier` and then either a keyword list or map\ncontaining the other properties you want to specify.\n\ne.g. `ConfigCat.User.new(\"IDENTIFIER\", email: \"user@example.com\")`","ref":"ConfigCat.User.html#new/2","title":"ConfigCat.User.new/2","type":"function"},{"doc":"Custom properties for additional targeting options.\n\nCan use either atoms or strings as keys; values must be strings.\nKeys are case-sensitive and must match the targeting rule exactly.","ref":"ConfigCat.User.html#t:custom/0","title":"ConfigCat.User.custom/0","type":"type"},{"doc":"Additional values for creating a `User` struct.\n\nCan be either a keyword list or a maps, but any keys that don't\nmatch the field names of `t:t()` will be ignored.","ref":"ConfigCat.User.html#t:options/0","title":"ConfigCat.User.options/0","type":"type"},{"doc":"The ConfigCat user object.","ref":"ConfigCat.User.html#t:t/0","title":"ConfigCat.User.t/0","type":"type"},{"doc":"# Contributing to the ConfigCat SDK for Elixir\n\nConfigCat SDK is an open source project. Feedback and contribution are welcome. Contributions are made to this repo via Issues and Pull Requests.","ref":"contributing.html","title":"Contributing to the ConfigCat SDK for Elixir","type":"extras"},{"doc":"The ConfigCat SDK team monitors the [issue tracker](https://github.com/configcat/elixir-sdk/issues) in the SDK repository. Bug reports and feature requests specific to this SDK should be filed in this issue tracker. The team will respond to all newly filed issues.","ref":"contributing.html#submitting-bug-reports-and-feature-requests","title":"Submitting bug reports and feature requests - Contributing to the ConfigCat SDK for Elixir","type":"extras"},{"doc":"We encourage pull requests and other contributions from the community. \n- Before submitting pull requests, ensure that all temporary or unintended code is removed.\n- Be accompanied by a complete Pull Request template (loaded automatically when a PR is created).\n- Add unit or integration tests for fixed or changed functionality.\n\nWhen you submit a pull request or otherwise seek to include your change in the repository, you waive all your intellectual property rights, including your copyright and patent claims for the submission. For more details please read the [contribution agreement](https://github.com/configcat/legal/blob/main/contribution-agreement.md).\n\nIn general, we follow the [\"fork-and-pull\" Git workflow](https://github.com/susam/gitpr)\n\n1. Fork the repository to your own Github account\n2. Clone the project to your machine\n3. Create a branch locally with a succinct but descriptive name\n4. Commit changes to the branch\n5. Following any formatting and testing guidelines specific to this repo\n6. Push changes to your fork\n7. Open a PR in our repository and follow the PR template so that we can efficiently review the changes.","ref":"contributing.html#submitting-pull-requests","title":"Submitting pull requests - Contributing to the ConfigCat SDK for Elixir","type":"extras"},{"doc":"Install [Elixir](https://elixir-lang.org) development environment.\n\nTo install dependencies:\n\n```bash\nmix local.rebar --force\nmix local.hex --force\nmix deps.get\n```","ref":"contributing.html#build-instructions","title":"Build instructions - Contributing to the ConfigCat SDK for Elixir","type":"extras"},{"doc":"```bash\nmix test\n```","ref":"contributing.html#running-tests","title":"Running tests - Contributing to the ConfigCat SDK for Elixir","type":"extras"},{"doc":"# ConfigCat SDK for Elixir\r\n\r\nhttps://configcat.com\r\n\r\nConfigCat SDK for Elixir provides easy integration for your application to ConfigCat.\r\n\r\nConfigCat is a feature flag and configuration management service that lets you separate releases from deployments. You can turn your features ON/OFF using [ConfigCat Dashboard](http://app.configcat.com) even after they are deployed. ConfigCat lets you target specific groups of users based on region, email or any other custom user attribute.\r\n\r\nConfigCat is a [hosted feature flag service](http://configcat.com). Manage feature toggles across frontend, backend, mobile, desktop apps. [Alternative to LaunchDarkly](http://configcat.com). Management app + feature flag SDKs.\r\n\r\n[![Elixir CI](https://github.com/configcat/elixir-sdk/actions/workflows/elixir-ci.yml/badge.svg?branch=main)](https://github.com/configcat/elixir-sdk/actions/workflows/elixir-ci.yml)\r\n[![Coverage Status](https://codecov.io/github/configcat/elixir-sdk/badge.svg?branch=main)](https://codecov.io/github/configcat/elixir-sdk?branch=main)\r\n[![Hex.pm](https://img.shields.io/hexpm/v/configcat.svg?style=circle)](https://hex.pm/packages/configcat)\r\n[![HexDocs.pm](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/configcat/)\r\n[![Hex.pm](https://img.shields.io/hexpm/dt/configcat.svg?style=circle)](https://hex.pm/packages/configcat)\r\n[![Hex.pm](https://img.shields.io/hexpm/l/configcat.svg)](https://hex.pm/packages/configcat)\r\n[![Last Updated](https://img.shields.io/github/last-commit/configcat/elixir-sdk.svg)](https://github.com/configcat/elixir-sdk/commits/main)\r\n\r\n\r\n# Getting Started\r\n\r\n#","ref":"readme.html","title":"ConfigCat SDK for Elixir","type":"extras"},{"doc":"```elixir\r\ndef deps do\r\n  [\r\n    {:configcat, \"~> 4.0.2\"}\r\n  ]\r\nend\r\n```\r\n\r\n#","ref":"readme.html#1-add-configcat-to-your-list-of-dependencies-in-mix-exs","title":"1. Add `configcat` to your list of dependencies in `mix.exs`: - ConfigCat SDK for Elixir","type":"extras"},{"doc":"![SDK-KEY](https://raw.githubusercontent.com/ConfigCat/elixir-sdk/main/assets/readme02-3.png  \"SDK-KEY\")\r\n\r\n#","ref":"readme.html#2-go-to-the-configcat-dashboard-to-get-your-sdk-key","title":"2. Go to the  ConfigCat Dashboard  to get your *SDK Key*: - ConfigCat SDK for Elixir","type":"extras"},{"doc":"```elixir\r\ndef start(_type, _args) do\r\n  children = [\r\n    {ConfigCat, [sdk_key: \"YOUR SDK KEY\"]},\r\n    MyApp\r\n  ]\r\n\r\n  opts = [strategy: :one_for_one, name: MyApp.Supervisor]\r\n  Supervisor.start_link(children, opts)\r\nend\r\n```\r\n\r\n#","ref":"readme.html#3-add-configcat-to-your-application-supervisor-tree","title":"3. Add `ConfigCat` to your application Supervisor tree: - ConfigCat SDK for Elixir","type":"extras"},{"doc":"```elixir\r\nisMyAwesomeFeatureEnabled = ConfigCat.get_value(\"isMyAwesomeFeatureEnabled\", false)\r\nif isMyAwesomeFeatureEnabled do\r\n  do_the_new_thing()\r\nelse\r\n  do_the_old_thing()\r\nend\r\n```","ref":"readme.html#4-get-your-setting-value","title":"4. Get your setting value: - ConfigCat SDK for Elixir","type":"extras"},{"doc":"Using this feature, you will be able to get different setting values for different users in your application by passing a `ConfigCat.User` object to the `ConfigCat.get_value/3` function.\r\n\r\nRead more about [Targeting here](https://configcat.com/docs/advanced/targeting/).\r\n\r\n```elixir\r\nuser = ConfigCat.User.new(\"#USER-IDENTIFIER#\")\r\n\r\nisMyAwesomeFeatureEnabled = ConfigCat.get_value(\"isMyAwesomeFeatureEnabled\", false, user)\r\nif isMyAwesomeFeatureEnabled do\r\n    do_the_new_thing()\r\nelse\r\n    do_the_old_thing()\r\nend\r\n```","ref":"readme.html#getting-user-specific-setting-values-with-targeting","title":"Getting user specific setting values with Targeting - ConfigCat SDK for Elixir","type":"extras"},{"doc":"- [Sample Console Apps](https://github.com/configcat/elixir-sdk/tree/main/samples)","ref":"readme.html#sample-demo-apps","title":"Sample/Demo apps - ConfigCat SDK for Elixir","type":"extras"},{"doc":"The ConfigCat SDK supports 3 different polling mechanisms to acquire the setting values from ConfigCat. After latest setting values are downloaded, they are stored in the internal cache then all requests are served from there. Read more about Polling Modes and how to use them at [ConfigCat Docs](https://configcat.com/docs/sdk-reference/elixir/).","ref":"readme.html#polling-modes","title":"Polling Modes - ConfigCat SDK for Elixir","type":"extras"},{"doc":"https://configcat.com/support","ref":"readme.html#need-help","title":"Need help? - ConfigCat SDK for Elixir","type":"extras"},{"doc":"Contributions are welcome. For more info please read the [Contribution Guideline](CONTRIBUTING.md).","ref":"readme.html#contributing","title":"Contributing - ConfigCat SDK for Elixir","type":"extras"},{"doc":"- [Official ConfigCat SDKs for other platforms](https://github.com/configcat)\r\n- [Documentation](https://configcat.com/docs)\r\n- [Blog](https://configcat.com/blog)","ref":"readme.html#about-configcat","title":"About ConfigCat - ConfigCat SDK for Elixir","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}